@@ -56,7 +56,7 @@ class PluginTmdbLookup(object):
                            imdb_id=imdb_id)
             entry.update_using_map(self.field_map, movie)
         except LookupError as e:
-            log.debug(u'Tmdb lookup for %s failed: %s' % (entry['title'], e.message))
+            log.info(u'Tmdb lookup failed for %s (%s)' % (entry['title'], e.message))
             # Set all of our fields to None if the lookup failed
             entry.unregister_lazy_fields(self.field_map, self.lazy_loader)
         return entry[field]
